@@ -5,6 +5,7 @@ from pydantic import BaseModel
 from pydantic.utils import ROOT_KEY
 from abc import ABC, abstractmethod
 from uuid import UUID
+import json
 
 
 # helper class
@@ -50,6 +51,17 @@ class LeafABC(BaseModel, ABC):
         pass
 
 
+class FactoryABC(BaseModel, ABC):
+
+    @classmethod
+    def add(self, element: Any) -> None:
+        pass
+
+    @classmethod
+    def create(self, nodes: str, data: dict) -> Any:
+        pass
+
+
 def set_key_from_input(value: Union[str, UUID, Type[LeafABC]]):
     """
     Helper method used as validator in pydantic model.
@@ -60,3 +72,13 @@ def set_key_from_input(value: Union[str, UUID, Type[LeafABC]]):
     if isinstance(value, str):
         return UUID(value)
     return value
+
+
+# helper class
+class UUIDEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, UUID):
+            # if the obj is uuid, we simply return the value of uuid
+            return str(obj)
+        return json.JSONEncoder.default(self, obj)
+
